<?php

use App\Models\Product;
use App\Models\Cart;
use App\Models\Option;
use App\Models\User;

use Carbon\Carbon;

if (!function_exists('inCart')) {
    function inCart($productId,$userId)
    {
        $cart = Cart::where(['product_id'=>$productId,'user_id'=>$userId,'ordered'=>0])->first();

        if($cart){
            return 1;
        }else{
            return 0;
        }
    }
}


if (!function_exists('cartId')) {
    function cartId($productId,$userId)
    {
        $cart = Cart::where(['product_id'=>$productId,'user_id'=>$userId,'ordered'=>0])->orderBy('created_at', 'desc')->first();

        if($cart){
            return $cart->id;
        }else{
            return 0;
        }
    }
}

if (!function_exists('cartAmount')) {
    function cartAmount($productId,$userId)
    {
        $amount = Cart::where(['product_id'=>$productId,'user_id'=>$userId,'ordered'=>0])->pluck('amount')->sum();
        if(!$amount) return 0;
        return $amount;
    }
}

if (!function_exists('cartOptions')) {
    function cartOptions($productId,$userId)
    {
        $cart = Cart::where(['product_id'=>$productId,'user_id'=>$userId,'ordered'=>0])->orderBy('created_at', 'desc')->first();
        if(!$cart) return [];
        $options = $cart->options;
        return $options;
    }
}

if (!function_exists('isRequired')) {
    function isRequired($product)
    {
        $extras = $product->extraProducts;
        foreach($extras as $extra){
           if($extra->extra->is_required) return 1;
        }

        return 0;
    }
}

if (!function_exists('cartPrice')) {
    function cartPrice($productId,$userId)
    {
        $cart = Cart::where(['product_id'=>$productId,'user_id'=>$userId,'ordered'=>0])->pluck('price')->sum();
        if(!$cart) return 0;
        return $cart;
    }
}

if (!function_exists('getOptions')) {
    function getOptions($extraId,$productId)
    {
        $options = Option::where(['product_id'=>$productId,'extra_id'=>$extraId])->get();

            return $options;
    }
}

if (!function_exists('getProducts')) {
    function getProducts($category, $keyword = null, $branchId = null)
    {
        if(Auth::guard('api')->check()){
            $branchId = auth("api")->user()->branch_id;
            $products =  Product::where('category_id',$category->id)->whereIn('branch_id',[$branchId,3]);
        }else{
            $products = Product::where('category_id',$category->id)->whereIn('branch_id',[$branchId,3]);
        }

        if($keyword){    
            $products->where(function($query) use ($keyword) {
                $query->where('name','LIKE','%'.$keyword.'%')
                        ->orWhere('name_ar','LIKE','%'.$keyword.'%');
            });
        }

        return $products->get();
    }
}

if (!function_exists('deliveryBoy')) {
    function deliveryBoy($deliveryId){
        $delivery = User::where('id',$deliveryId)->first();
    
        if($delivery){
            return $delivery->name;
        }else{
            return '-';
        }
    }
}

if (!function_exists('statusNoti')) {
    function statusNoti($status)
    {
        switch($status){
            case 'pending':
                $noti = 'Your Order is Pending';
                break;
        
            case 'pickedup':
                $noti = 'Your Order is Picked Up';
                break;
            
            case 'on_road':
                $noti = 'Your Order is on Road';
                break;

            case 'deliveried':
                $noti = 'Your Order is Delivered';
                break;

            case 'failed':
                $noti = 'Your Order is Failed';
                break;
        
            default:
            $noti = 'Your Order Updated';

        }

        return $noti;
    }
}

if (!function_exists('statusNotiAr')) {
    function statusNotiAr($status)
    {
        switch($status){
            case 'pending':
                $noti = 'طلبك في حالة الانتظار';
                break;
        
            case 'pickedup':
                $noti = 'تم استلام طلبك';
                break;
            
            case 'on_road':
                $noti = 'طلبك في الطريق';
                break;

            case 'deliveried':
                $noti = 'تم توصيل طلبك بنجاح';
                break;

            case 'failed':
                $noti = 'تم رفض طلبك';
                break;
        
            default:
            $noti = 'تم تحديث حالة طلبك';

        }

        return $noti;
    }
}