<?php

namespace App\Http\Controllers\Application;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Events\NotificationCreatedEvent;
use Illuminate\Support\Facades\Auth;

use App\Http\Resources\AddressesResource;
use App\Http\Resources\AddressResource;

use App\Models\Address;
use App\Models\User;


class AddressController extends Controller
{
    public function addresses(){

        $user = auth()->user();
        $addresses = Address::where('user_id',$user->id)->get();

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'addresses' => AddressesResource::make($addresses),
            )
        ];

        return response($response, 201); 
    }

    public function create(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'address' => 'required|string',
            'address_details' => 'required|string',
            'latitude' => 'required|numeric',
            'longitude' => 'required|numeric',
            'label_as' => 'required|string|in:Home,Work,Other',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }
            
        $address = Address::create([
            'address' => $request->address,
            'address_details' => $request->address_details,
            'latitude' => $request->latitude,
            'longitude' => $request->longitude,
            'label_as' => $request->label_as,
            'user_id' => auth()->user()->id,
        ]);

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'address' => AddressResource::make($address),
            )
        ];

        return response($response, 201); 
    }

    public function update(Request $request,$id)
    {
        $validator = Validator::make($request->all(), [
            'address' => 'required|string',
            'address_details' => 'required|string',
            'latitude' => 'required|numeric',
            'longitude' => 'required|numeric',
            'label_as' => 'required|string|in:Home,Work,Other',
        ]);
            
        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }

        $address = Address::where('id',$id)->first();

        if(!$address){
            return response()->json([
                'success' => false,
                'message' => $request->lang == 'en' ? 'Address Doesn\'t Exist' : 'العنوان غير موجود'
            ], 400);
        }

        $address->update([
            'address' => $request->address,
            'address_details' => $request->address_details,
            'latitude' => $request->latitude,
            'longitude' => $request->longitude,
            'label_as' => $request->label_as,
            'user_id' => auth()->user()->id,
        ]);

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'address' => AddressResource::make($address),
            )
        ];

        return response($response, 201); 
    }

    public function show(Request $request,$id)
    {
        $address = Address::where('id',$id)->first();

        if(!$address){
            return response()->json([
                'success' => false,
                'message' => $request->lang == 'en' ? 'Address Doesn\'t Exist' : 'العنوان غير موجود'
            ], 400);
        }

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'address' => AddressResource::make($address),
            )
        ];

        return response($response, 201); 
    }

    public function delete(Request $request,$id){
        $cart = Address::where('id',$id)->delete();
        if($cart){
            $response = [
                'success' => true,
                'message' => $request->lang == 'en' ? "Address Deleted Successfully" : "تم حذف العنوان بنجاح",
            ];
            return response($response, 201);
        }else{
            $response = [
                'success' => false,
                'message' => $request->lang == 'en' ? "Address Doesn\'t Exist" : "العنوان غير موجود",
            ];
            return response($response, 400);
        }
    }
}