<?php

namespace App\Http\Controllers\Application;

use Twilio\Rest\Client;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Rule;

use App\Http\Resources\UserResource;
use App\Http\Resources\NotificationResource;
use App\Http\Resources\ARNotificationResource;

use App\Models\Role;
use App\Models\User;
use App\Models\Device;
use App\Models\Cart;
use App\Models\UserNotification;


class CustomerController extends Controller
{
    public function register(Request $request){
        $validator = Validator::make($request->all(), [
            'name'=>'nullable|string',
            'branch'=>'required|integer|digits:1,2',
            'phone' => 'required|numeric|unique:users,phone',
            'address'=>'required|string',
            'firebase_token' => 'nullable|string',
            'lang'=>'required|string|in:en,ar',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }

        $user = new User;

        $user->phone = $request->phone;
        $user->name = $request->name;
        $user->address = $request->address;
        $user->branch_id = $request->branch;
        $user->role_id = 2;
        $user->lang = $request->lang;
        $user->save();

        if($request->firebase_token){
            Device::create([
                'firebase_token'=>$request->firebase_token,
                'user_id'=>$user->id
            ]);
        }

        $token = $user->createToken('myapptoken')->accessToken;

        $response = [
            'success' => true,
            'message' => "Customer Created Successfully.",
            "data" => array(
                'token' =>  $token,
                'user' => UserResource::make($user),
            )
        ];
        return response($response, 201);
    }

    public function login(Request $request){
        $validator = Validator::make($request->all(), [
            'phone' => 'required|string',
            'branch'=>'required|integer|digits:1,2',
            'firebase_token' => 'nullable|string',

        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }
        $user = User::where('phone',$request->phone)->first();

        if(!$user){
            return response([
                'success' => false,
                'message' => 'Phone Number isn\'t Correct.'
            ], 400);
        }

        $user->update([
            'branch_id' => $request->branch,
            'is_out' => 0
        ]);

        if($request->firebase_token){
            $device = Device::where(['user_id'=>$user->id,'firebase_token'=>$request->firebase_token])->first();
            
            if(!$device){
                Device::create([
                    'firebase_token'=>$request->firebase_token,
                    'user_id'=>$user->id
                ]);
            }
        }

        $token = $user->createToken('myapptoken')->accessToken;
        $response = [
            'success' => true,
            'message' => "User Logged in Successfully.",
            "data" => array(
                'token' =>  $token,
                'user' => UserResource::make($user),
            )
        ];
        return response($response, 201);
    }

    public function Profile(){
        $user = auth()->user();

                
            $response = [
                'success' => true,
                'message' => "Profile Info.",
                "data" => array(
                    'user' => UserResource::make($user),
                )   
            ];

            return response($response, 201);
    }

    public function logout(Request $request){
        auth()->user()->update([
            'is_out' => 1
        ]);

        auth()->user()->tokens()->delete();
        return [
            'message' =>'Logged Out'
        ];
    }

    public function branch(Request $request){
        $validator = Validator::make($request->all(), [
            'branch'=>'required|integer|digits:1,2',

        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }
        $user = auth()->user();

        if(!$user){
            return response([
                'success' => false,
                'message' => 'User Doesn\'t Exist.'
            ], 400);
        }

        $user->update([
            'branch_id' => $request->branch
        ]);

        $cartItems = Cart::where(['user_id'=>$user->id,'ordered'=>0])->whereHas('product', function($query) use ($user) {
            return $query->whereNotIn('branch_id', [$user->branch_id,3]);
        })->get();

        $cartItems->each(function ($cartItem) {
            $cartItem->delete();
        });

        $response = [
            'success' => true,
            'message' => "Branch Updated Successfully.",
            "data" => array(
                'user' => UserResource::make($user),
            )
        ];
        return response($response, 201);
    }

    public function lang(Request $request){
        $validator = Validator::make($request->all(), [
            'lang'=>'required|string|in:en,ar',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }
        
        $user = auth()->user();
        $user->update([
            'lang' => $request->lang
        ]);

        $response = [
            'success' => true,
            'message' => "Language Updated Successfully.",
            "data" => array(
                'user' => UserResource::make($user),
            )
        ];
        return response($response, 201);
    }

    public function allNotification(Request $request){
        // $notifications = Notification::where('user_id',auth()->user()->id)->paginate(10);
        $user = auth()->user();
        $notifications = UserNotification::where('user_id',$user->id)->orderBy('created_at','desc')->paginate(10);
        $response = [
            'success' => true,
            'message' => "The process is completed successfully.is_active",
            "data" => array(
                // 'user' => UserResource::make($user),
                'notifications' => $request->lang == 'en' ? NotificationResource::make($notifications) : ARNotificationResource::make($notifications),
            ),
        ];
        return response($response, 201);
    }

}
