<?php

namespace App\Http\Controllers\Application;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Resources\OrdersResource;
use Illuminate\Support\Facades\Validator;
use App\Events\NotificationCreatedEvent;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Rule;
use App\Models\User;
use App\Models\Order;
use App\Models\Cart;
use App\Models\CartOrder;
use App\Models\Notification;
use App\Models\UserNotification;
use Carbon\Carbon;

class DeliveryBoyController extends Controller
{
    public function home(Request $request){
        $user = auth()->user();
        $orders = Order::where('delivery_id',$user->id)->whereNotIn('status',['deliveried','failed'])->get();
        $oldOrders = Order::where('delivery_id',$user->id)->whereIn('status',['deliveried','failed'])->get();
        
        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'live_orders' => OrdersResource::make($orders),
                'old_orders' => OrdersResource::make($oldOrders),
            )
        ];
        return response($response, 201);
    }

    public function status(Request $request,$id){
        $validator = Validator::make($request->all(), [
            'status' => 'required|string',
            'estimated_time' => 'nullable|string',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }

        $order = Order::findOrFail($id);

        $order->update([
            'status' => $request->status,
            'estimated_time' => $request->estimated_time
        ]);

        $notification = Notification::create([
            'title'=>'Order Status',
            'body'=>statusNoti($request->status),
            'title_ar'=>'حالة الطلب',
            'body_ar'=>statusNotiAr($request->status),
            'body_ar'=>statusNotiAr($request->status),
            'order_id'=>$id,
        ]);

        $userNoti = UserNotification::create([
            'user_id'=>$order->user_id,
            'notification_id'=>$notification->id,
        ]);

        $receiver_id = User::where(['id'=>$order->user_id, 'is_out', 0])->pluck('id')->toArray();

        if($order->user->lang == "en"){
            $noti = [
                'title'=>$notification->title,
                'body'=>$notification->body,
            ];
        }else{
            $noti = [
                'title'=>$notification->title_ar,
                'body'=>$notification->body_ar,
            ];
        }
        event(new NotificationCreatedEvent($noti,$receiver_id));

        $response = [
            'success' => true,
            'message' => "Order has been Sent Successfully.",
            "data" => array(
                "order_id" => $order->id,
                "order_number" => $order->order_number,
                "order_status" => $order->status,
                "order_estimated_time" => $order->estimated_time,
                "ordered_at" => $order->created_at->toDayDateTimeString()
            )

        ];
        return response($response, 201);
    }

    public function map(Request $request,$id){
        $userId = auth()->user()->id;
        $order = Order::findOrFail($id);
        $carts = $order->carts;
        $subTotal = $order->total_price - $order->delivery_price > 0 ? $order->total_price - $order->delivery_price : 0;
        $countItems =$carts->sum('amount');

        if($order->type == "Delivery"){
            $delivery = $order->delivery_price;
        }else{
            $delivery = 0;
        }

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                "order_number" => $order->order_number,
                "order_status" => $order->status,
                'latitude' => $order->address_id ? $order->oAddress->latitude : $order->latitude,
                'longitude' => $order->address_id ? $order->oAddress->longitude : $order->longitude,
                'address_name' => $order->address_id ? $order->oAddress->address : $order->address,
                'address' => $order->address_id ? $order->oAddress->address_details : $order->address_details,
                "sub_total" => $subTotal,
                "delivery" => $delivery,
                "total_price" => $order->total_price,
                "count_items" => $countItems,
                "customer" => $order->user->name,
                'customer_phone' => $order->user->phone,
            )
        ];

        return response($response, 201); 
    }
}
