<?php

namespace App\Http\Controllers\Application;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Helpers\Helper;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;

use App\Http\Resources\CategoriesResource;
use App\Http\Resources\BannersResource;
use App\Http\Resources\SlidersResource;
use App\Http\Resources\ProductsResource;
use App\Http\Resources\AllProductsResource;
use App\Http\Resources\ArAllProductsResource;
use App\Http\Resources\CategoryResource;
use App\Http\Resources\ProductResource;
use App\Http\Resources\ExtraResource;

use App\Http\Resources\ArCategoriesResource;
use App\Http\Resources\ArProductsResource;
use App\Http\Resources\ArCategoryResource;
use App\Http\Resources\ArProductResource;
use App\Http\Resources\ArExtraResource;

use App\Models\Banner;
use App\Models\Category;
use App\Models\Slider;
use App\Models\Product;
use App\Models\Cart;

class HomeController extends Controller
{
    public function home(Request $request){

        if(Auth::guard('api')->check()){
            $branchId = auth("api")->user()->branch_id;
            $bestSeller = Product::whereIn('branch_id',[$branchId,3])
                                  ->where('image_best_seller','<>',null)->get();
            $topDeals = Product::whereIn('branch_id',[$branchId,3])
                                ->where('category_id',1)->orderBy('id', 'asc')->take(2)->get();
        }else{
            $bestSeller = Product::whereIn('branch_id',[$request->branch_id,3])
                                  ->where('image_best_seller','<>',null)->get();
            $topDeals = Product::whereIn('branch_id',[$request->branch_id,3])
                                ->where('category_id',1)->orderBy('id', 'desc')->take(2)->get();
        }
        
        if( $request->lang == 'en'){
            $response = [
                'success' => true,
                'message' => "The Process is Completed Successfully",
                "data" => array(
                    'categories' => CategoriesResource::make(Category::orderBy('id', 'asc')->get()),
                    'banner' => BannersResource::make(Banner::first()),
                    'sliders' => SlidersResource::make(Slider::all()),
                    'best_seller' => ProductsResource::make($bestSeller),
                    'top_deals' => ProductsResource::make($topDeals)

                )
            ];
        }else{
            $response = [
                'success' => true,
                'message' => "The Process is Completed Successfully",
                "data" => array(
                    'categories' => ArCategoriesResource::make(Category::orderBy('id', 'DESC')->get()),
                    'banner' => BannersResource::make(Banner::first()),
                    'sliders' => SlidersResource::make(Slider::all()),
                    'best_seller' => ArProductsResource::make($bestSeller),
                    'top_deals' => ArProductsResource::make($topDeals)

                )
            ];
        }

        return response($response, 201);
    }

    public function products(Request $request)
    {
        if(Auth::guard('api')->check()){
            $user = auth("api")->user();
            $carts = Cart::where(['user_id'=>$user->id,'ordered'=>0]);
            $totalPrice = $carts->sum('price');
            $countItems =$carts->sum('amount');
        }else{
            $totalPrice = 0;
            $countItems =0;
        }

        $categories = Category::orderBy('id', 'asc')->get();
        
        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "total_price" => $totalPrice,
            "count_items" => $countItems,
            "data" => array(
                'category' =>  $request->lang == 'en' ? CategoriesResource::make($categories) : ArCategoriesResource::make($categories),
            )
        ];

        return response($response, 201); 
    }

    public function product(Request $request,$productId){

        $product = Product::where('id',$productId)->first();
        if(!$product){
            return response()->json([
                'success' => false,
                'message' => $request->lang == 'en' ? 'product not exist' : 'المنتج غير موجود',
            ], 400);
        }

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'product' => $request->lang == 'en' ? ProductResource::make($product) : ArProductResource::make($product),
            )
        ];

        return response($response, 201); 
    }
}