<?php

namespace App\Http\Controllers\Application;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Events\NotificationCreatedEvent;
use Illuminate\Support\Facades\Auth;
use App\Models\Coupon;
use App\Models\CouponUser;
use App\Models\User;
use App\Models\Order;
use App\Models\CartOption;
use App\Models\Cart;
use App\Models\Product;
use App\Models\UserNotification;
use App\Models\StaticContent;

use Carbon\Carbon;

use App\Http\Resources\CartsResource;
use App\Http\Resources\CouponsResource;
use App\Http\Resources\OrdersResource;
use App\Http\Resources\ProductResource;
use App\Http\Resources\ProductsResource;

use App\Http\Resources\ARCartsResource;
use App\Http\Resources\ArProductsResource;

class OrderController extends Controller
{
    public function coupons(Request $request){

        $user = auth()->user();
        $time = Carbon::now();
        $userCoupon = CouponUser::where('user_id',$user->id)->where('is_off',1)->pluck('coupon_id');

        $coupons = Coupon::where('expire_date', '>' ,$time)
                        ->whereNotIn('id',$userCoupon)
                        ->orderBy('created_at', 'DESC');
        
        if($request->keyword){
            $coupons->where(function($query) use ($request) {
                $query->where('code','LIKE','%'.$request->keyword.'%');
            });
        }
        
        $coupons = $coupons->get();

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'coupons' => CouponsResource::make($coupons),
            )
        ];

        return response($response, 201); 
    }

    public function order(Request $request){
        $validator = Validator::make($request->all(), [
            'coupon_id' => 'nullable|integer|exists:coupons,id',
            'address_id' => 'nullable|integer|exists:addresses,id',
            'total_price' => 'required|integer',
            'type' => 'required|string|in:Delivery,Take Away,Dine In',
            'address' => 'nullable|string',
            'address_details' => 'nullable|string',
            'address_name' => 'nullable|string',
            'latitude' => 'nullable|numeric',
            'longitude' => 'nullable|numeric',
            'note' => 'nullable|string',

        ]);

        if ($validator->fails()) {
            return response()->json([
                'success' => false,
                'message' => 'Please See Errors Parameter for all Errors.',
                'errors' => $validator->errors()
            ], 400);
        }

        $user = auth()->user();
        // $couponUser = CouponUser::where(['user_id'=>$user->id,'coupon_id'=>$request->coupon_id])->first();
        // $coupon = Coupon::where('id',$request->coupon_id)->first();

        // if($couponUser){
        //     if($couponUser->is_off == 1 || $couponUser->times_used >= $coupon->times_used){
        //         $response = [
        //             'success' => true,
        //             'message' => "This Coupon doesn\'t Available.",
        //         ];
        //         return response($response, 201);
        //     }
        // }
        $items = Cart::where(['user_id'=>$user->id,'ordered'=>0]);

        if($items->count() != 0){
            // $totalPrice = $items->sum('price');
            $cartItems = $items->get();

            // if($coupon){
            //     if($coupon->type == 'Percent'){
            //         $totalPrice = $totalPrice - ($coupon->value * $totalPrice)/100;
            //     }else{
            //         $totalPrice = $totalPrice -$coupon->value;
            //     }
            // }
            $static = StaticContent::first();

            $order = Order::create([
                'user_id' => $user->id,
                'address' => $request->address,
                'address_details' => $request->address_details,
                'address_name' => $request->address_name,
                'latitude' => $request->latitude,
                'longitude' => $request->longitude,
                'address_id' => $request->address_id,
                'coupon_id' => $request->coupon_id,
                'type' => $request->type,
                'note' => $request->note,
                'total_price' => $request->total_price,
                'delivery_price' => $static->delivery_fee,
                'ordered_at' => Carbon::now(),
                'order_number' =>  Order::generateOrderNumber(),
                'status' => 'pending',
            ]);

            if($order){
                foreach($cartItems as $cartItem){
                    $cartItem->update([
                        'ordered' => 1,
                        'order_id' => $order->id,
                    ]);
                }
                // $receiver_id = User::where('role_id',3)->pluck('id')->toArray();
                // $notification = Notification::create([
                //     'title'=>'Order',
                //     'body'=>'There is a New Order'
                // ]);
                // event(new NotificationCreatedEvent($notification,$receiver_id));

                $response = [
                    'success' => true,
                    'message' => "Order has been Sent Successfully.",
                    "data" => array(
                        "order_id" => $order->id,
                        "order_number" => $order->order_number,
                        "ordered_at" => $order->created_at->toDayDateTimeString()
                    )

                ];
                return response($response, 201);
            }else{
                $response = [
                    'success' => false,
                    'message' => "Something Went Wrong!",
                ];
                return response($response, 400);
            }
        }else{
            $response = [
                'success' => true,
                'message' => "No Items in Cart.",
            ];
            return response($response, 201);
        }
    }

    public function getOrders(){
        $user = auth()->user();
        $orders = Order::with(['oAddress'])->where('user_id',$user->id)->where(function($query) {
                                                        $query->where('status','deliveried')
                                                        ->orWhere('status', 'failed');
                                                    })->orderBy('id', 'desc')->get();
        $liveOrders = Order::with(['oAddress'])->where('user_id',$user->id)->where(function($query) {
                                                            $query->where('status', '!=', 'deliveried')
                                                            ->where('status', '!=', 'failed');
                                                        })->orderBy('id', 'desc')->get();

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'Today_orders' => OrdersResource::make($liveOrders),
                'orders' => OrdersResource::make($orders),
            )
        ];

        return response($response, 201); 
    }

    public function getOrderStatus($id){
        $user = auth()->user();
        $order = Order::where('id',$id)->first();
        $delivery = User::where('id',$order->delivery_id)->first();

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                "order_number" => $order->order_number,
                "ordered_at" => $order->created_at->toDayDateTimeString(),
                'status' => $order->status,
                'estimated_time' => $order->estimated_time,
                'delivery_boy_name' => $delivery ? $delivery->name : null,
                'delivery_boy_phone' => $delivery ? $delivery->phone : null,
            )
        ];

        return response($response, 201); 
    }

    public function reorder(Request $request,$orderId){
        $user = auth()->user();
        $reordered = Order::findORFail($orderId);
        $carts = Cart::where(['user_id'=>$user->id,'order_id'=>$orderId]);
        $products = Product::orderBy('created_at','DESC')->limit(5)->get();
        $subTotal = $carts->sum('price');
        $countItems =$carts->sum('amount');
        $carts = $carts->get();

        if($countItems == 0){
            return response()->json([
                'success' => false,
                'message' => $request->lang == 'en' ? 'Cart is Empty' : 'السلة فارغة'
            ], 400);
        }

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'carts' => $request->lang == 'en' ? CartsResource::make($carts) :  ARCartsResource::make($carts),
                "sub_total" => $subTotal,
                "delivery" => 6000,
                "total_price" => $subTotal + 6000,
                "count_items" => $countItems,
                'products' =>  $request->lang == 'en' ? ProductsResource::make($products) :  ArProductsResource::make($products)
            )
        ];

        return response($response, 201);
    }

    public function delete($id)
    {

        $order = Order::where('user_id', auth()->user()->id)->where('id', $id)->where('status', 'pending')->first();
        if($order){
            $order->carts->each(function ($cart) {
                $cart->delete();
            });
            $order = $order->delete();

            if($order){
                $response = [
                    'success' => true,
                    'message' => "Order Deleted Successfully.",
                ];
                return response($response, 201);  
            }else{
                $response = [
                    'success' => false,
                    'message' => "Something Went Wrong!",
                ];
                return response($response, 400);
            }   
        }else{
            $response = [
                'success' => false,
                'message' => "Something Went Wrong!",
            ];
            return response($response, 400);
        }          
    }

    public function orderInfo(Request $request,$id,$notiId){
        $userId = auth()->user()->id;
        $order = Order::findOrFail($id);
        $noti = UserNotification::findOrFail($notiId);
        $carts = $order->carts;
        $subTotal = $order->total_price - $order->delivery_price > 0 ? $order->total_price - $order->delivery_price : 0;
        $countItems =$carts->sum('amount');
        // $carts = $carts->get();

        if($order->type == "Delivery"){
            $delivery = $order->delivery_price;
        }else{
            $delivery = 0;
        }

        $response = [
            'success' => true,
            'message' => "The Process is Completed Successfully",
            "data" => array(
                'carts' => $request->lang == 'en' ? CartsResource::make($carts) :  ARCartsResource::make($carts),
                "order_number" => $order->order_number,
                "notification_status" => $noti->notification->status,
                "order_status" => $order->status,
                'latitude' => $order->address_id ? $order->oAddress->latitude : $order->latitude,
                'longitude' => $order->address_id ? $order->oAddress->longitude : $order->longitude,
                'address_name' => $order->address_id ? $order->oAddress->address : $order->address,
                'address' => $order->address_id ? $order->oAddress->address_details : $order->address_details,
                "sub_total" => $subTotal,
                "delivery" => $delivery,
                "total_price" => $order->total_price,
                "count_items" => $countItems,
            )
        ];

        return response($response, 201); 
    }
}