<?php

namespace App\Http\Controllers\Dashboard;

use App\Http\Controllers\Controller;
use App\Models\Address;
use App\Models\User;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use  Illuminate\Validation\Validator;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;

class AddressController extends Controller
{

    public function index(Request $request)
    {
        $addresses = Address::all();

        return view('pages.addresses.listaddresses', ['addresses' => $addresses]);
    }
    public function create()
    {
        $users = User::whereNotIn('role_id', [1, 3])->get();

        return view('pages.addresses.addressescreate', ['users' => $users]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'address' => 'required|string',
            'address_details' => 'required|string',
            'latitude' => 'required|numeric',
            'longitude' => 'required|numeric',
            'label_as' => 'required|string|in:Home,Work,Other',
        ]);
            
        Address::create([
            'address' => $request->address,
            'address_details' => $request->address_details,
            'latitude' => $request->latitude,
            'longitude' => $request->longitude,
            'label_as' => $request->label_as,
            'user_id' => $request->user_id,
        ]);

        return redirect()->route('addresseslist')
            ->with('success', 'Address Created Successfully.');
    }
    public function edit($id)
    {
        
        $address = Address::where('id', $id)->get();
        $users = User::whereNotIn('role_id', [1, 3])->get();

        $data = [
            'address' => $address,
            'users' => $users
        ];
        return view('pages.addresses.addressesedit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $address = Address::where('id', $id)->first();

        $request->validate([
            'address' => 'required|string',
            'address_details' => 'required|string',
            'latitude' => 'required|numeric',
            'longitude' => 'required|numeric',
            'label_as' => 'required|string|in:Home,Work,Other',
        ]);

        $request->address != null ? $address->address = $request->address : null;
        $request->address_details != null ? $address->address_details = $request->address_details : null;
        $request->latitude != null ? $address->latitude = $request->latitude : null;
        $request->longitude != null ? $address->longitude = $request->longitude : null;
        $request->label_as != null ? $address->label_as = $request->label_as : null;

        $address->save();

        return redirect()->route('addresseslist')
            ->with('success', 'Address Updated Successfully.');
    }


    public function delete($id)
    {

        Address::where('id', $id)->delete();

        return redirect()->route('addresseslist')
             ->with('success', 'Address Deleted Successfully.');
    }
}
