<?php

namespace App\Http\Controllers\Dashboard;

use App\Http\Controllers\Controller;
use App\Models\Coupon;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use  Illuminate\Validation\Validator;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;

class CouponController extends Controller
{

    public function index(Request $request)
    {
        $coupons = Coupon::all();

        return view('pages.coupons.listcoupons', ['coupons' => $coupons]);
    }
    public function create()
    {
        return view('pages.coupons.couponscreate');
    }

    public function store(Request $request)
    {
        $request->validate([
            'code'=>'required|string',
            'value'=>'required|integer',
            'type' => 'required|string|in:Fixed,Percent',
            'times_used' => 'required|integer',
            'expire_date' => 'required|date',
        ]);
            
        Coupon::create([
            'code' => $request->code,
            'value' => $request->value,
            'type' => $request->type,
            'times_used' => $request->times_used,
            'expire_date' => $request->expire_date,
        ]);

        return redirect()->route('couponslist')
            ->with('success', 'Coupon Created Successfully.');
    }
    public function edit($id)
    {
        
        $coupon = Coupon::where('id', $id)->get();
 
        $data = [
            'coupon' => $coupon,
        ];
        return view('pages.coupons.couponsedit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $coupon = Coupon::where('id', $id)->first();

        $request->validate([
            'code'=>'required|string',
            'value'=>'required|integer',
            'type' => 'required|string|in:Fixed,Percent',
            'times_used' => 'required|integer',
            'expire_date' => 'required|date',
        ]);

        $request->code != null ? $coupon->code = $request->code : null;
        $request->value != null ? $coupon->value = $request->value : null;
        $request->type != null ? $coupon->type = $request->type : null;
        $request->times_used != null ? $coupon->times_used = $request->times_used : null;
        $request->expire_date != null ? $coupon->expire_date = $request->expire_date : null;

        $coupon->save();

        return redirect()->route('couponslist')
            ->with('success', 'Coupon Updated Successfully.');
    }


    public function delete($id)
    {

        Coupon::where('id', $id)->delete();

        return redirect()->route('couponslist')
             ->with('success', 'Coupon Deleted Successfully.');
    }
}
