<?php

namespace App\Http\Controllers\Dashboard;

use App\Http\Controllers\Controller;
use App\Models\Order;
use App\Models\Role;
use App\Models\User;
use App\Models\Notification;
use App\Models\UserNotification;
use App\Models\StaticContent;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use  Illuminate\Validation\Validator;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;

use App\Events\NotificationCreatedEvent;

class OrderController extends Controller
{
    public function index(Request $request)
    {
        $orders = Order::orderBy('id', 'desc')->get();
        $deliveries = User::where('role_id', 3)->get();

        return view('pages.orders.listorders', ['orders' => $orders,'deliveries' => $deliveries]);
    }

    public function update(Request $request, $id)
    {
        $order = Order::findOrFail($id);
        $request->status != null ? $order->status = $request->status : null;
        $request->delivery_id != null ? $order->delivery_id = $request->delivery_id : null;
        $request->estimated_time != null ? $order->estimated_time = $request->estimated_time : null;

        $order->save();

        $notification = Notification::create([
            'title'=>'Order Status',
            'body'=>statusNoti($request->status),
            'title_ar'=>'حالة الطلب',
            'body_ar'=>statusNotiAr($request->status),
            'order_id'=>$id,
            'status'=>$order->status,
        ]);

        $notificationBoy = Notification::create([
            'title'=>'New Order',
            'body'=>'There is a new order',
            'title_ar'=>'طلب جديد',
            'body_ar'=>'يوجد طلب جديد',
            'order_id'=>$id,
            'status'=>$order->status,
        ]);

        $userNoti = UserNotification::create([
            'user_id'=>$order->user_id,
            'notification_id'=>$notification->id,
        ]);

        $boyNoti = UserNotification::create([
            'user_id'=>$order->delivery_id,
            'notification_id'=>$notificationBoy->id,
        ]);

        $receiver_id = User::where(['id'=>$order->user_id, 'is_out', 0])->pluck('id')->toArray();
        $receiver_boy_id = User::where(['id'=>$order->delivery_id, 'is_out', 0])->pluck('id')->toArray();

        if($order->user->lang == "en"){
            $noti = [
                'title'=>$notification->title,
                'body'=>$notification->body,
            ];
        }else{
            $noti = [
                'title'=>$notification->title_ar,
                'body'=>$notification->body_ar,
            ];
        }

        if($order->boy->lang == "en"){
            $notiBoy = [
                'title'=>$notificationBoy->title,
                'body'=>$notificationBoy->body,
            ];
        }else{
            $notiBoy = [
                'title'=>$notificationBoy->title_ar,
                'body'=>$notificationBoy->body_ar,
            ];
        }

        event(new NotificationCreatedEvent($noti,$receiver_id));
        event(new NotificationCreatedEvent($notiBoy,$receiver_boy_id));

        return redirect()->route('orderslist')
            ->with('success', 'Status Updated Successfully.');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */



    public function delete($id)
    {
        $order = Order::where('id', $id)->first();

        if($order){
            $order->carts->each(function ($cart) {
                $cart->delete();
            });
            $order = $order->delete();
        }

        return redirect()->route('orderslist')
             ->with('success', 'Order Deleted Successfully.');
    }
    public function info($id)
    {
        $order = Order::findOrFail($id);
        $staticcontent = StaticContent::first();

        return view('pages.orders.info', ['order' => $order,
                                          'staticcontent' => $staticcontent
                                         ]);

    }
}
