<?php

namespace App\Http\Controllers\Dashboard;

use App\Http\Controllers\Controller;
use App\Models\Product;
use App\Models\ExtraProduct;
use App\Models\Category;
use App\Models\Extra;
use App\Models\Option;
use App\Models\Size;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Validator;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;



class ProductController extends Controller
{
    public function index(Request $request)
    {
        $products = Product::all();

        return view('pages.products.listproducts', ['products' => $products]);
       
    }
    public function create()
    {
        $categories = Category::all();
        $extras =Extra::all();

        $data = [  
            'categories' => $categories ,
            'extras' => $extras     
    
        ];

        return view('pages.products.productscreate',$data);
    }

    public function store(Request $request)
    {
        $request->validate([
            'name'=>'required|string',
            'name_ar'=>'required|string',
            'description'=>'required|string',
            'description_ar'=>'required|string',
            'discount_price'=>'nullable|numeric',
            'price'=>'required|numeric',
            'image' => 'required|mimes:png,jpg,jpeg,webp',
            'image_best_seller' => 'nullable|mimes:png,jpg,jpeg,webp',
            'category' => 'required|integer|exists:categories,id',
            'branch'=>'required|integer|digits:1,2',
        ]);

        if ($request->has('image')) {
            //get file name with extention
            $filenameWithExt = $request->image->getClientOriginalName();
            //get just file name
            $filename = pathinfo($filenameWithExt, PATHINFO_FILENAME);
            //GET EXTENTION
            $extention = $request->image->getClientOriginalExtension();
            //file name to store
            $fileNameToStore = $filename . '.' . $extention;
            //upload image
            $path = $request->image->storeAs('public/images/products/images', $fileNameToStore);
            $url = asset('public/storage/images/products/images/' . $fileNameToStore);
         
        }
        $url2 = null;
        if ($request->has('image_best_seller')) {
            //get file name with extention
            $filenameWithExt2 = $request->image_best_seller->getClientOriginalName();
            //get just file name
            $filename2 = pathinfo($filenameWithExt2, PATHINFO_FILENAME);
            //GET EXTENTION
            $extention2 = $request->image_best_seller->getClientOriginalExtension();
            //file name to store
            $fileNameToStore2 = $filename2 . '.' . $extention2;
            //upload image
            $path2 = $request->image_best_seller->storeAs('public/images/products/images', $fileNameToStore2);
            $url2 = asset('public/storage/images/products/images/' . $fileNameToStore2);
        
        }

       $product = Product::create([
            'name' => $request->name,
            'name_ar' => $request->name_ar,
            'description' => $request->description,
            'description_ar' => $request->description_ar,
            'discount_price' => $request->discount_price ? $request->discount_price : 0 ,
            'price' => $request->price,
            'image' => $url,
            'image_best_seller' => $url2,
            'category_id'=>$request->category,
            'branch_id' => $request->branch,
        ]);

        $ids = $request->input('extraid');
        $prices = $request->input('extraprice');
        $optionName = $request->input('extraname');
        $optionNameAr = $request->input('extranamear');
        if($ids){
            for($i=0;$i<count($ids);$i++){
                $exPr =ExtraProduct::where(['extra_id'=>$ids[$i],'product_id'=>$product->id])->first();
                if(!$exPr){
                    $extraOption = ExtraProduct::create([
                        'extra_id' => $ids[$i],
                        'product_id' => $product->id,
                    ]);
                }
                $extraOption = Option::create([
                    'extra_id' => $ids[$i],
                    'product_id' => $product->id,
                    'name' => $optionName[$i],
                    'name_ar' => $optionNameAr[$i],
                    'price' => $prices[$i] ? $prices[$i] : 0
                ]);
            }
        }

        // $sizeName = $request->input('size');
        // $sizeNameAr = $request->input('sizear');
        // $sizePrice = $request->input('sizeprice');
        // if($sizeName){
        //     for($i=0;$i<count($sizeName);$i++){
        //         $size = Size::create([
        //             'name' => $sizeName[$i],
        //             'name_ar' => $sizeNameAr[$i],
        //             'price' => $sizePrice[$i] ? $sizePrice[$i] : 0,
        //             'product_id' => $product->id,
        //         ]);
        //     }
        // }


        return redirect()->route('productslist')
            ->with('success', 'Product Created Successfully.');
    }
    public function edit($id)
    {
        $product = Product::where('id', $id)->get();
        $extraProducts = ExtraProduct::where('product_id', $id)->pluck('extra_id')->toArray();
        $options = Option::where('product_id',$id)->get();
        $extras = Extra::all();
        $categories = Category::all();

        $data = [
            'categories' => $categories,
            'product' => $product,
            'extras' => $extras,
            'extraProducts' => $extraProducts,
            'options' => $options

        ];
        return view('pages.products.productsedit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $product =  Product::where('id', $id)->first();

        $request->validate([
            'name'=>'required|string',
            'name_ar'=>'required|string',
            'description'=>'required|string',
            'description_ar'=>'required|string',
            'discount_price'=>'nullable|numeric',
            'price'=>'required|numeric',
            'image' => 'nullable|mimes:png,jpg,jpeg,webp',
            'image_best_seller' => 'nullable|mimes:png,jpg,jpeg,webp',
            'category' => 'required|integer|exists:categories,id',
            'branch'=>'required|integer|digits:1,2',
        ]);

        $request->name != null ? $product->name = $request->name : null;
        $request->name_ar != null ? $product->name_ar = $request->name_ar : null;
        $request->description != null ? $product->description = $request->description : null;
        $request->description_ar != null ? $product->description_ar = $request->description_ar : null;
        $request->price != null ? $product->price = $request->price : null;
        $request->discount_price != null ? $product->discount_price = $request->discount_price : null;
        $request->category != null ? $product->category_id = $request->category : null;
        $request->branch != null ? $product->branch_id = $request->branch : null;

        if ($request->has('image')) {
            //get file name with extention
            $filenameWithExt = $request->image->getClientOriginalName();
            //get just file name
            $filename = pathinfo($filenameWithExt, PATHINFO_FILENAME);
            //GET EXTENTION
            $extention = $request->image->getClientOriginalExtension();
            //file name to store
            $fileNameToStore = $filename . '.' . $extention;
            //upload image
            $path = $request->image->storeAs('public/images/products/images', $fileNameToStore);
            $url = asset('public/storage/images/products/images/' . $fileNameToStore);
            $product->image = $url;

         }

         if ($request->has('image_best_seller')) {
            //get file name with extention
            $filenameWithExt2 = $request->image_best_seller->getClientOriginalName();
            //get just file name
            $filename2 = pathinfo($filenameWithExt2, PATHINFO_FILENAME);
            //GET EXTENTION
            $extention2 = $request->image_best_seller->getClientOriginalExtension();
            //file name to store
            $fileNameToStore2 = $filename2 . '.' . $extention2;
            //upload image
            $path2 = $request->image_best_seller->storeAs('public/images/products/images', $fileNameToStore2);
            $url2 = asset('public/storage/images/products/images/' . $fileNameToStore2);
            $product->image_best_seller = $url2;
        }

        $product->save();
        
        $extraProduct = ExtraProduct::where('product_id',$product->id)->delete();
        $options = Option::where('product_id',$product->id)->delete();

        $ids = $request->input('extraid');
        $prices = $request->input('extraprice');
        $optionName = $request->input('extraname');
        $optionNameAr = $request->input('extranamear');
        if($ids){
            for($i=0;$i<count($ids);$i++){
                $extraOption = ExtraProduct::updateOrCreate([
                    'extra_id' => $ids[$i],
                    'product_id' => $product->id,

                ],[
                    'extra_id' => $ids[$i],
                    'product_id' => $product->id,
                ]);
                $extraOption = Option::create([
                    'extra_id' => $ids[$i],
                    'product_id' => $product->id,
                    'name' => $optionName[$i],
                    'name_ar' => $optionNameAr[$i],
                    'price' => $prices[$i] ? $prices[$i] : 0
                ]);
            }
        }

        // $sizes = Size::where('product_id',$product->id)->delete();

        // $sizeName = $request->input('size');
        // $sizeNameAr = $request->input('sizear');
        // $sizePrice = $request->input('sizeprice');
        // if($sizeName){
        //     for($i=0;$i<count($sizeName);$i++){
        //         if($sizeName[$i] != null){
        //             $size = Size::create([
        //                 'name' => $sizeName[$i],
        //                 'name_ar' => $sizeNameAr[$i],
        //                 'price' => $sizePrice[$i] ? $sizePrice[$i] : 0,
        //                 'product_id' => $product->id,
        //             ]);
        //         }
        //     }
        // }
        
        return redirect()->route('productslist')
            ->with('success', 'Product Updated Successfully.');
    }


    public function delete($id)
    {

        Product::where('id', $id)->delete();

        return redirect()->route('productslist')
             ->with('success', 'Product Deleted Successfully.');
    }

    public function allSubCategories(Request $request){
        $subCategories = SubCategory::where('id',$request->category_id)->get();
        if ($subCategories) {
            return $subCategories;
        }
    }

    public function optionDelete($id){
        $option = ExtraOption::FindOrFail($id);
        // dd($subservice);
        $option->delete();
        return redirect()->back()->with('success', 'Option has been deleted successfully!');
    }
    public function favorites(Request $request)
    {
        $products = Product::where('favorite','>',0)->orderBy('favorite','DESC')->limit(50)
        ->get();
// dd( $products);
        return view('pages.products.favoriteproducts', ['products' => $products]);
    }
        

       
}
