<?php

namespace App\Http\Controllers\Dashboard;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Role;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use  Illuminate\Validation\Validator;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rule;

class UserController extends Controller
{
    public function index(Request $request)
    {
        $users = User::where('role_id',2)->get();

        return view('pages.users.listusers', ['users' => $users]); 
    }

    public function indexDeliveryBoy(Request $request)
    {
        $users = User::where('role_id',3)->get();

        return view('pages.users.listboys', ['users' => $users]); 
    }

    public function create()
    {
        $roles = Role::where('id','<>',1)->get();

        $data = [
            'roles' => $roles,
       
        ];
        return view('pages.users.userscreate',$data);
    }

    public function store(Request $request)
    {
        $request->validate([
            'name'=>'nullable|string',
            'branch'=>'required|integer|digits:1,2',
            'phone' => 'required|numeric|unique:users,phone',
            'role' => 'required|integer|exists:roles,id',
            'address'=>'required|string',
        ]);


       $user = User::create([
            'name' => $request->name,
            'address' => $request->address,
            'phone' => $request->phone,
            'role_id'=>$request->role,
            'branch_id' => $request->branch,
        ]);

        if($user->role_id == 2){
            return redirect()->route('userslist')
                ->with('success', 'User Created Successfully.');
        }else{
            return redirect()->route('boyslist')
            ->with('success', 'User Created Successfully.');
        }
    }
    public function edit($id)
    {
        $user = User::where('id', $id)->get();
        $roles = Role::where('id','<>',1)->get();

        $data = [
            'roles' => $roles,
            'user' => $user,
       
        ];
        return view('pages.users.usersedit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $user = User::where('id', $id)->first();

        $request->validate([
            'name'=>'nullable|string',
            'branch'=>'required|integer|digits:1,2',
            'phone' => 'required|numeric|'.Rule::unique('users')->ignore($user->id),
            'role' => 'required|integer|exists:roles,id',
            'address'=>'required|string',
        ]);

        $request->name != null ? $user->name = $request->name : null;
        $request->branch != null ? $user->branch_id = $request->branch : null;
        $request->address != null ? $user->address = $request->address : null;
        $request->phone != null ? $user->phone = $request->phone : null;
        $request->role != null ? $user->role_id = $request->role : null;

        $user->save();

        if($user->role_id == 2){
            return redirect()->route('userslist')
                ->with('success', 'User Updated Successfully.');
        }else{
            return redirect()->route('boyslist')
                ->with('success', 'User Updated Successfully.');
        }
    }


    public function delete($id)
    {

        User::where('id', $id)->delete();

        return redirect()->back()
             ->with('success', 'User Deleted Successfully.');
    }

}
