<?php

namespace App\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;

class OrdersResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $orders = array();
        foreach ($this->resource as $order) {
            $orders[] = array(        
                'id' => $order->id,
                'order_number' => $order->order_number,
                'total_price' => $order->total_price,
                'delivery_price' => $order->delivery_price,
                'subtotal_price' => $order->total_price - $order->delivery_price > 0 ? $order->total_price - $order->delivery_price : 0,
                'status' => $order->status,
                'address' => $order->address,
                'address_details' => $order->address_details,
                'address_name' => $order->address_name,
                'latitude' => $order->latitude,
                'longitude' => $order->longitude,
                'type' => $order->type,
                'ordered_at' => $order->created_at->toDayDateTimeString(),
                'note' => $order->note,
                'estimated_time' => $order->estimated_time,
                'customer_id' => $order->user_id,
                'customer_name' => $order->user->name,
                'coupon_id' => $order->coupon_id,
                'coupon_code' => $order->coupon ? $order->coupon->code : null,
                'user_address' => new AddressResource($order->oAddress),
                'carts' => $request->lang == 'en' ? new CartsResource($order->carts) : new ARCartsResource($order->carts),
            );
        }
        return $orders;
    }
}
