<?php

namespace App\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;
use App\Models\Product;
use App\Models\Category;
use App\Models\Extra;
use App\Models\Option;
use App\Models\ExtraProduct;
use App\Helpers\Helper;
use Illuminate\Support\Facades\Auth;

class ProductsResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array|\Illuminate\Contracts\Support\Arrayable|\JsonSerializable
     */
    public function toArray($request)
    {
        $products = array();
        foreach ($this->resource as $product) {
            $products[] = array(
        
                'id' => $product->id,
                'name' => $product->name,
                'description' => $product->description,
                'price' => $product->price,
                'discount_price' => $product->discount_price,
                'image' => $product->image,
                'image_best_seller' => $product->image_best_seller,
                'branch_id' => $product->branch_id,
                'category' => $product->category->name,
                'category_id' => $product->category->id,
                'category_image' => $product->category->image,
                'is_required' => isRequired($product),
                'in_cart' => Auth::guard('api')->check() ? inCart($product->id,auth("api")->user()->id) : 0,
                'cart_amount' => Auth::guard('api')->check() ? cartAmount($product->id,auth("api")->user()->id) : 0,
                'cart_price' => Auth::guard('api')->check() ? cartPrice($product->id,auth("api")->user()->id) : 0,
                'last_cart_id' => Auth::guard('api')->check() ? cartId($product->id,auth("api")->user()->id) : 0,
                'cart_option' => Auth::guard('api')->check() ? new ExtraOptionHomeResource(cartOptions($product->id,auth("api")->user()->id)) : [],
                'extras' => new ExtraResource($product->extraProducts),
            );
        }
        return $products;
    }
}
