<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateOrdersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('orders', function (Blueprint $table) {
            $table->id();
            $table->string('order_number');
            $table->integer('total_price');
            $table->string('status');
            $table->enum('type',['Delivery', 'Take Away', 'Dine In']);
            $table->integer('estimated_time')->nullable();
            $table->string('address')->nullable();
            $table->string('address_name')->nullable();
            $table->string('address_details')->nullable();
            $table->decimal('longitude', 8, 6);
            $table->decimal('latitude', 8, 6);
            $table->text('note')->nullable();
            $table->foreignId('delivery_id')->nullable();
            $table->foreignId('user_id');
            $table->foreign('user_id')
                ->references('id')
                ->on('users')
                ->onDelete('cascade');
            $table->foreignId('coupon_id')->nullable();
            $table->foreign('coupon_id')
                ->references('id')
                ->on('coupons');
            $table->foreignId('address_id')->nullable();
            $table->foreign('address_id')
                ->references('id')
                ->on('addresses');

            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('orders');
    }
}
