<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Application\CustomerController;
use App\Http\Controllers\Application\SliderController;
use App\Http\Controllers\Application\HomeController;
use App\Http\Controllers\Application\ProductController;
use App\Http\Controllers\Application\CartController;
use App\Http\Controllers\Application\OrderController;
use App\Http\Controllers\Application\AddressController;
use App\Http\Controllers\Application\StaticContentController;
use App\Http\Controllers\Application\DeliveryBoyController;


/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::group(['prefix'=>'/customer'], function(){
	Route::controller(CustomerController::class)->group(function(){
        Route::post('/register', 'register');
        Route::post('/login', 'login');
        Route::post('/forgot-password', 'changePassword');
        Route::post('/check-phone', 'phone');

    });
});

Route::controller(HomeController::class)->group(function(){
    Route::post('/home', 'home');
    Route::post('/products', 'products');
    Route::post('/product/{product_id}', 'product');
});

Route::controller(StaticContentController::class)->group(function(){
    Route::get('/static-content', 'staticContent');
    Route::get('/faqs', 'faqs');

});

Route::group(['middleware'=>['auth:api']],function(){

    Route::controller(CustomerController::class)->group(function(){
        Route::post('/branch', 'branch');
        Route::get('/notification', 'allNotification');
        Route::post('/lang', 'lang');
        Route::post('/logout', 'logout');
    });

    Route::controller(OrderController::class)->group(function(){
        Route::post('/order-info/{id}/{noti}', 'orderInfo');
    });
});

Route::group(['middleware'=>['auth:api','customer']],function(){

    Route::controller(CartController::class)->group(function(){
        Route::post('/my-cart', 'myCarts');
        Route::post('/add-to-cart/{product_id}', 'addToCart');
        Route::post('/add-item/{product_id}', 'changeAmount');
        Route::delete('/delete-cart-item/{item_id}','deleteCartItem');

    });

    Route::controller(AddressController::class)->group(function(){
        Route::get('/addresses', 'addresses');
        Route::post('/create-address', 'create');
        Route::post('/show-address/{id}', 'show');
        Route::post('/update-address/{id}', 'update');
        Route::delete('/delete-address/{id}','delete');

    });

    Route::controller(OrderController::class)->group(function(){
        Route::post('/coupons', 'coupons');
        Route::post('/order', 'order');
        Route::post('/re-order/{id}', 'reorder');
        Route::get('/user-order', 'getOrders');
        Route::post('/order-status/{id}', 'getOrderStatus');
        Route::delete('/delete-order/{id}', 'delete');

    });
});

Route::group(['prefix'=>'/delivery-boy','middleware'=>['auth:api','deliveryBoy']],function(){

    Route::controller(DeliveryBoyController::class)->group(function(){
        Route::get('/home', 'home');
        Route::get('/order-map/{order_id}', 'map');
        Route::post('/status-order/{order_id}', 'status');

    });
    
});

Route::middleware('auth:api')->get('/user', function (Request $request) {
    return $request->user();
});
